==> funHDDC_2.0.tar.gz: funHDDC/man/plot.mfpca.Rd <==
\name{plot.mfpca}
\alias{plot.mfpca}
\title{Graphical representation for MFPCA}
\usage{
  \method{plot}{mfpca}(x,nharm,threshold,...)
}
\description{
Graphical representations for MFPCA: smoothed data plots, scores plots, variation of the mean curve and eigenfunction plots.
}
\arguments{
  \item{x}{An object produced by mfpca function.}
  \item{nharm}{The number of harmonics for which you want graphical representations, default value is 3.}
  \item{threshold}{The threshold of proportion of variance that stop plotting, default value is 0.05.}
  \item{...}{Arguments to be passed to methods, such as graphical parameters.}
}
\value{
\item{Data plot}{ plot of all smooth curves for each functional variable.}
\item{Scores plots}{plot of curves coordinates on the number of eigenfunctions/harmonics selected and depending on the threshold choosen.}
\item{Mean curve plots}{ plot of variation of the mean curve. Variations are estimated based on the mean values with addition (red) and substraction (blue) of each eigenfunction.}
\item{Eigenfunction plots}{ visualization of each eigenfunction/harmonic selected and depending on the threshold choosen.}
}
\references{
- C. Bouveyron and J. Jacques, Model-based Clustering of Time Series in Group-specific Functional Subspaces, Advances in Data Analysis and Classification, vol. 5 (4), pp. 281-300, 2011.
- A. Schmutz, C. Bouveyron, J. Jacques, L. Cheze and  P. Martin, Clustering multivariate functional data in group-specic functional subspaces, Preprint HAL 01652467, Université Côte d'Azur, 2017.
}
\examples{
  library(fda)

  ####Univariate case: "Canadian temperature" data (Ramsey & Silverman)
  daybasis65 <- create.fourier.basis(c(0, 365), nbasis=65, period=365)
  daytempfd <- smooth.basis(day.5, CanadianWeather$dailyAv[,,"Temperature.C"], daybasis65,
                            fdnames=list("Day", "Station", "Deg C"))$fd

  res.pca<-mfpca(daytempfd)
  plot(res.pca,nharm=4)


  ####Multivariate case: "Canadian temperature" data (Ramsey & Silverman)
  daybasis65 <- create.fourier.basis(c(0, 365), nbasis=65, period=365)
  daytempfd <- smooth.basis(day.5, CanadianWeather$dailyAv[,,"Temperature.C"], daybasis65,
                            fdnames=list("Day", "Station", "Deg C"))$fd
  dayprecfd<-smooth.basis(day.5, CanadianWeather$dailyAv[,,"Precipitation.mm"], daybasis65,
                          fdnames=list("Day", "Station", "Mm"))$fd

  res.pca<-mfpca(list(daytempfd,dayprecfd))
  plot(res.pca,nharm=4)

}

==> funHDDC_2.1.0.tar.gz: funHDDC/man/plot.mfpca.Rd <==
\name{plot.mfpca}
\alias{plot.mfpca}
\title{Graphical representation for MFPCA}
\usage{
  \method{plot}{mfpca}(x,nharm,threshold,...)
}
\description{
It provides graphical representations for MFPCA: smoothed data plots, scores plots, variation of the mean curve      and eigenfunction plots.
}
\arguments{
  \item{x}{An object produced by mfpca function.}
  \item{nharm}{The number of harmonics for which you want graphical representations, default value is 3.}
  \item{threshold}{The threshold of proportion of variance that stop plotting, default value is 0.05.}
  \item{...}{Additional parameters to pass to subfunctions.}
}
\value{
\item{Data plot}{ plot of all smooth curves for each functional variable.}
\item{Scores plots}{plot of curves coordinates on the number of eigenfunctions/harmonics selected and depending on the threshold choosen.}
\item{Mean curve plots}{ plot of variation of the mean curve. Variations are estimated based on the mean values with addition (red) and substraction (blue) of each eigenfunction.}
\item{Eigenfunction plots}{ visualization of each eigenfunction/harmonic selected and depending on the threshold choosen.}
}
\examples{
  ## Univariate case: "Canadian temperature" data (Ramsey & Silverman)
  daybasis65 <- create.fourier.basis(c(0, 365), nbasis=65, period=365)
  daytempfd <- smooth.basis(day.5, CanadianWeather$dailyAv[,,"Temperature.C"], daybasis65,
                            fdnames=list("Day", "Station", "Deg C"))$fd

  res.pca<-mfpca(daytempfd)
  plot(res.pca,nharm=4)


  ## Multivariate case: "Canadian temperature" data (Ramsey & Silverman)
  daybasis65 <- create.fourier.basis(c(0, 365), nbasis=65, period=365)
  daytempfd <- smooth.basis(day.5, CanadianWeather$dailyAv[,,"Temperature.C"], daybasis65,
                            fdnames=list("Day", "Station", "Deg C"))$fd
  dayprecfd<-smooth.basis(day.5, CanadianWeather$dailyAv[,,"Precipitation.mm"], daybasis65,
                          fdnames=list("Day", "Station", "Mm"))$fd

  res.pca<-mfpca(list(daytempfd,dayprecfd))
  plot(res.pca,nharm=4)

}
